"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DayPicker = DayPicker;
const react_1 = __importStar(require("react"));
const UI_js_1 = require("./UI.js");
const getClassNamesForModifiers_js_1 = require("./helpers/getClassNamesForModifiers.js");
const getComponents_js_1 = require("./helpers/getComponents.js");
const getDataAttributes_js_1 = require("./helpers/getDataAttributes.js");
const getDateLib_js_1 = require("./helpers/getDateLib.js");
const getDefaultClassNames_js_1 = require("./helpers/getDefaultClassNames.js");
const getDropdownMonths_js_1 = require("./helpers/getDropdownMonths.js");
const getDropdownYears_js_1 = require("./helpers/getDropdownYears.js");
const getFormatters_js_1 = require("./helpers/getFormatters.js");
const getStyleForModifiers_js_1 = require("./helpers/getStyleForModifiers.js");
const getWeekdays_js_1 = require("./helpers/getWeekdays.js");
const defaultLabels = __importStar(require("./labels/index.js"));
const useCalendar_js_1 = require("./useCalendar.js");
const useDayPicker_js_1 = require("./useDayPicker.js");
const useFocus_js_1 = require("./useFocus.js");
const useModifiers_js_1 = require("./useModifiers.js");
const useSelection_js_1 = require("./useSelection.js");
/**
 * Render the date picker calendar.
 *
 * @group DayPicker
 * @see http://daypicker.dev
 */
function DayPicker(props) {
    const { captionLayout, dir, locale, ISOWeek, mode, modifiersClassNames, modifiersStyles, numberOfMonths = 1, onDayBlur, onDayClick, onDayFocus, onDayKeyDown, onPrevClick, onNextClick, showWeekNumber, styles, weekStartsOn, firstWeekContainsDate, useAdditionalWeekYearTokens, useAdditionalDayOfYearTokens } = props;
    const { components, formatters, labels, dateLib, classNames } = (0, react_1.useMemo)(() => ({
        dateLib: (0, getDateLib_js_1.getDateLib)(props.dateLib),
        components: (0, getComponents_js_1.getComponents)(props.components),
        formatters: (0, getFormatters_js_1.getFormatters)(props.formatters),
        labels: { ...defaultLabels, ...props.labels },
        classNames: { ...(0, getDefaultClassNames_js_1.getDefaultClassNames)(), ...props.classNames }
    }), [
        props.classNames,
        props.components,
        props.dateLib,
        props.formatters,
        props.labels
    ]);
    const { formatCaption, formatDay, formatMonthDropdown, formatWeekNumber, formatWeekNumberHeader, formatWeekdayName, formatYearDropdown } = formatters;
    const calendar = (0, useCalendar_js_1.useCalendar)(props, dateLib);
    const { months, navigationStartMonth, navigationEndMonth, previousMonth, nextMonth, goToPreviousMonth, goToNextMonth, goToMonth } = calendar;
    const modifiers = (0, useModifiers_js_1.useModifiers)(props, calendar, dateLib);
    const selection = (0, useSelection_js_1.useSelection)(props, dateLib);
    const { isSelected, handleSelect } = selection;
    const focus = (0, useFocus_js_1.useFocus)(props, calendar, modifiers, selection, dateLib);
    const { isFocusTarget, focused: focusedDay, setFocused, blur, focusDayBefore, focusDayAfter, focusWeekBefore, focusWeekAfter, focusMonthBefore, focusMonthAfter, focusYearBefore, focusYearAfter, focusStartOfWeek, focusEndOfWeek } = focus;
    const { labelDayButton, labelGridcell, labelGrid, labelMonthDropdown, labelNav, labelNext, labelPrevious, labelWeekday, labelWeekNumber, labelWeekNumberHeader, labelYearDropdown } = labels;
    const weekdays = (0, react_1.useMemo)(() => (0, getWeekdays_js_1.getWeekdays)(locale, weekStartsOn, ISOWeek, dateLib), [ISOWeek, dateLib, locale, weekStartsOn]);
    const isInteractive = mode !== undefined || onDayClick !== undefined;
    const handlePreviousClick = (0, react_1.useCallback)(() => {
        if (!previousMonth)
            return;
        goToPreviousMonth();
        onPrevClick?.(previousMonth);
    }, [goToPreviousMonth, onPrevClick, previousMonth]);
    const handleNextClick = (0, react_1.useCallback)(() => {
        if (!nextMonth)
            return;
        goToNextMonth();
        onNextClick?.(nextMonth);
    }, [goToNextMonth, nextMonth, onNextClick]);
    const handleDayClick = (0, react_1.useCallback)((day, m) => {
        return (e) => {
            e.preventDefault();
            e.stopPropagation();
            handleSelect(day.date, m, e);
            setFocused(day);
            onDayClick?.(day.date, m, e);
        };
    }, [handleSelect, onDayClick, setFocused]);
    const handleDayFocus = (0, react_1.useCallback)((day, m) => {
        return (e) => {
            setFocused(day);
            onDayFocus?.(day.date, m, e);
        };
    }, [onDayFocus, setFocused]);
    const handleDayBlur = (0, react_1.useCallback)((day, m) => {
        return (e) => {
            blur();
            onDayBlur?.(day.date, m, e);
        };
    }, [blur, onDayBlur]);
    const handleDayKeyDown = (0, react_1.useCallback)((day, modifiers) => {
        return (e) => {
            switch (e.key) {
                case "ArrowLeft":
                    e.preventDefault();
                    e.stopPropagation();
                    dir === "rtl" ? focusDayAfter() : focusDayBefore();
                    break;
                case "ArrowRight":
                    e.preventDefault();
                    e.stopPropagation();
                    dir === "rtl" ? focusDayBefore() : focusDayAfter();
                    break;
                case "ArrowDown":
                    e.preventDefault();
                    e.stopPropagation();
                    focusWeekAfter();
                    break;
                case "ArrowUp":
                    e.preventDefault();
                    e.stopPropagation();
                    focusWeekBefore();
                    break;
                case " ":
                case "Enter":
                    e.preventDefault();
                    e.stopPropagation();
                    selection?.handleSelect(day.date, modifiers, e);
                    break;
                case "PageUp":
                    e.preventDefault();
                    e.stopPropagation();
                    e.shiftKey ? focusYearBefore() : focusMonthBefore();
                    break;
                case "PageDown":
                    e.preventDefault();
                    e.stopPropagation();
                    e.shiftKey ? focusYearAfter() : focusMonthAfter();
                    break;
                case "Home":
                    e.preventDefault();
                    e.stopPropagation();
                    focusStartOfWeek();
                    break;
                case "End":
                    e.preventDefault();
                    e.stopPropagation();
                    focusEndOfWeek();
                    break;
            }
            onDayKeyDown?.(day.date, modifiers, e);
        };
    }, [
        dir,
        focusDayAfter,
        focusDayBefore,
        focusEndOfWeek,
        focusMonthAfter,
        focusMonthBefore,
        focusStartOfWeek,
        focusWeekAfter,
        focusWeekBefore,
        focusYearAfter,
        focusYearBefore,
        onDayKeyDown,
        selection
    ]);
    const formatOptions = {
        locale,
        weekStartsOn,
        firstWeekContainsDate,
        useAdditionalWeekYearTokens,
        useAdditionalDayOfYearTokens
    };
    const labelOptions = formatOptions;
    const { className, style } = (0, react_1.useMemo)(() => ({
        className: [classNames[UI_js_1.UI.Root], props.className]
            .filter(Boolean)
            .join(" "),
        style: { ...styles?.[UI_js_1.UI.Root], ...props.style }
    }), [classNames, props.className, props.style, styles]);
    const dataAttributes = (0, react_1.useMemo)(() => (0, getDataAttributes_js_1.getDataAttributes)(props), [props]);
    const contextValue = (0, react_1.useMemo)(() => ({ ...calendar, ...selection, ...modifiers }), [calendar, modifiers, selection]);
    return (react_1.default.createElement(useDayPicker_js_1.dayPickerContext.Provider, { value: contextValue },
        react_1.default.createElement(components.Root, { className: className, style: style, dir: props.dir, id: props.id, lang: props.lang, nonce: props.nonce, title: props.title, "data-interactive": isInteractive || undefined, "data-multiple-months": numberOfMonths > 1 || undefined, "data-week-numbers": showWeekNumber || undefined, ...dataAttributes },
            react_1.default.createElement(components.Months, { className: classNames[UI_js_1.UI.Months], style: styles?.[UI_js_1.UI.Months] },
                !props.hideNavigation && (react_1.default.createElement(components.Nav, { role: "navigation", className: classNames[UI_js_1.UI.Nav], style: styles?.[UI_js_1.UI.Nav], "aria-label": labelNav() },
                    react_1.default.createElement(components.Button, { type: "button", className: classNames[UI_js_1.UI.ButtonPrevious], tabIndex: calendar.previousMonth ? undefined : -1, disabled: calendar.previousMonth ? undefined : true, "aria-label": labelPrevious(previousMonth, labelOptions), onClick: handlePreviousClick },
                        react_1.default.createElement(components.Chevron, { disabled: previousMonth ? undefined : true, className: classNames[UI_js_1.UI.Chevron], orientation: "left" })),
                    react_1.default.createElement(components.Button, { type: "button", className: classNames[UI_js_1.UI.ButtonNext], tabIndex: nextMonth ? undefined : -1, disabled: nextMonth ? undefined : true, "aria-label": labelNext(nextMonth, labelOptions), onClick: handleNextClick },
                        react_1.default.createElement(components.Chevron, { disabled: previousMonth ? undefined : true, orientation: "right", className: classNames[UI_js_1.UI.Chevron] })))),
                months.map((calendarMonth, displayIndex) => {
                    const handleMonthChange = (e) => {
                        const selectedMonth = Number(e.target.value);
                        const month = dateLib.setMonth(dateLib.startOfMonth(calendarMonth.date), selectedMonth);
                        goToMonth(month);
                    };
                    const handleYearChange = (e) => {
                        const month = dateLib.setYear(dateLib.startOfMonth(calendarMonth.date), Number(e.target.value));
                        goToMonth(month);
                    };
                    const dropdownMonths = (0, getDropdownMonths_js_1.getDropdownMonths)(calendarMonth.date, navigationStartMonth, navigationEndMonth, formatters, locale, dateLib);
                    const dropdownYears = (0, getDropdownYears_js_1.getDropdownYears)(months[0].date, navigationStartMonth, navigationEndMonth, formatters, dateLib);
                    return (react_1.default.createElement(components.Month, { className: classNames[UI_js_1.UI.Month], style: styles?.[UI_js_1.UI.Month], key: displayIndex, displayIndex: displayIndex, calendarMonth: calendarMonth },
                        react_1.default.createElement(components.MonthCaption, { className: classNames[UI_js_1.UI.MonthCaption], style: styles?.[UI_js_1.UI.MonthCaption], calendarMonth: calendarMonth, displayIndex: displayIndex }, captionLayout?.startsWith("dropdown") ? (react_1.default.createElement(components.DropdownNav, { className: classNames[UI_js_1.UI.DropdownNav], style: styles?.[UI_js_1.UI.DropdownNav] },
                            captionLayout === "dropdown" ||
                                captionLayout === "dropdown-months" ? (react_1.default.createElement(components.Dropdown, { "aria-label": labelMonthDropdown(), classNames: classNames, components: components, disabled: Boolean(props.disableNavigation), onChange: handleMonthChange, options: dropdownMonths, style: styles?.[UI_js_1.UI.Dropdown], value: calendarMonth.date.getMonth() })) : (react_1.default.createElement("span", { role: "status", "aria-live": "polite" }, formatMonthDropdown(calendarMonth.date.getMonth()))),
                            captionLayout === "dropdown" ||
                                captionLayout === "dropdown-years" ? (react_1.default.createElement(components.Dropdown, { "aria-label": labelYearDropdown(labelOptions), classNames: classNames, components: components, disabled: Boolean(props.disableNavigation), onChange: handleYearChange, options: dropdownYears, style: styles?.[UI_js_1.UI.Dropdown], value: calendarMonth.date.getFullYear() })) : (react_1.default.createElement("span", { role: "status", "aria-live": "polite" }, formatYearDropdown(calendarMonth.date.getFullYear()))))) : (react_1.default.createElement(components.CaptionLabel, { className: classNames[UI_js_1.UI.CaptionLabel], role: "status", "aria-live": "polite" }, formatCaption(calendarMonth.date, formatOptions, dateLib)))),
                        react_1.default.createElement(components.MonthGrid, { role: "grid", "aria-multiselectable": mode === "multiple" || mode === "range", "aria-label": labelGrid(calendarMonth.date, labelOptions, dateLib) ||
                                undefined, className: classNames[UI_js_1.UI.MonthGrid], style: styles?.[UI_js_1.UI.MonthGrid] },
                            react_1.default.createElement(components.Weekdays, { className: classNames[UI_js_1.UI.Weekdays], hidden: props.hideWeekdayRow, role: "row", style: styles?.[UI_js_1.UI.Weekdays] },
                                showWeekNumber && (react_1.default.createElement(components.WeekNumberHeader, { "aria-label": labelWeekNumberHeader(labelOptions), className: classNames[UI_js_1.UI.WeekNumberHeader], role: "columnheader", style: styles?.[UI_js_1.UI.WeekNumberHeader] }, !props.hideWeekdayRow && formatWeekNumberHeader())),
                                weekdays.map((weekday, i) => (react_1.default.createElement(components.Weekday, { "aria-label": labelWeekday(weekday, labelOptions, dateLib), className: classNames[UI_js_1.UI.Weekday], key: i, role: "columnheader", style: styles?.[UI_js_1.UI.Weekday] }, formatWeekdayName(weekday, formatOptions, dateLib))))),
                            react_1.default.createElement(components.Weeks, { className: classNames[UI_js_1.UI.Weeks], role: "rowgroup", style: styles?.[UI_js_1.UI.Weeks] }, calendarMonth.weeks.map((week, weekIndex) => {
                                return (react_1.default.createElement(components.Week, { className: classNames[UI_js_1.UI.Week], key: week.weekNumber, role: "row", style: styles?.[UI_js_1.UI.Week], week: week },
                                    showWeekNumber && (react_1.default.createElement(components.WeekNumber, { week: week, role: "rowheader", style: styles?.[UI_js_1.UI.WeekNumber], "aria-label": labelWeekNumber(week.weekNumber, {
                                            locale
                                        }), className: classNames[UI_js_1.UI.WeekNumber] }, formatWeekNumber(week.weekNumber))),
                                    week.days.map((day) => {
                                        const { date } = day;
                                        const dayModifiers = modifiers.getModifiers(day);
                                        const focused = focusedDay?.isEqualTo(day);
                                        if (!dayModifiers.hidden && focused)
                                            dayModifiers[UI_js_1.DayFlag.focused] = true;
                                        const selected = isSelected(date) || dayModifiers.selected;
                                        dayModifiers[UI_js_1.SelectionState.selected] =
                                            !dayModifiers.disabled && selected;
                                        if (!dayModifiers.disabled && mode === "range") {
                                            const range = selection;
                                            dayModifiers[UI_js_1.SelectionState.range_start] =
                                                range.isRangeStart(date);
                                            dayModifiers[UI_js_1.SelectionState.range_end] =
                                                range.isRangeEnd(date);
                                            dayModifiers[UI_js_1.SelectionState.range_middle] =
                                                range.isRangeMiddle(date);
                                        }
                                        const style = {
                                            ...(0, getStyleForModifiers_js_1.getStyleForModifiers)(dayModifiers, modifiersStyles),
                                            ...styles?.[UI_js_1.UI.Day]
                                        };
                                        const className = [
                                            classNames[UI_js_1.UI.Day],
                                            ...(0, getClassNamesForModifiers_js_1.getClassNamesForModifiers)(dayModifiers, classNames, modifiersClassNames)
                                        ];
                                        const ariaLabel = !isInteractive
                                            ? labelGridcell(date, dayModifiers, labelOptions, dateLib)
                                            : undefined;
                                        const dataAttributes = {
                                            "data-day": dateLib.format(date, "yyyy-MM-dd"),
                                            "data-month": day.outside
                                                ? dateLib.format(date, "yyyy-MM")
                                                : undefined
                                        };
                                        return (react_1.default.createElement(components.Day, { key: `${dateLib.format(date, "yyyy-MM-dd")}_${dateLib.format(day.displayMonth, "yyyy-MM")}`, day: day, modifiers: dayModifiers, role: "gridcell", className: className.join(" "), style: style, "aria-hidden": dayModifiers.hidden || undefined, "aria-selected": dayModifiers.selected || undefined, "aria-label": ariaLabel, ...dataAttributes }, isInteractive ? (react_1.default.createElement(components.DayButton, { className: classNames[UI_js_1.UI.DayButton], style: styles?.[UI_js_1.UI.DayButton], day: day, modifiers: dayModifiers, disabled: dayModifiers.disabled || undefined, tabIndex: isFocusTarget(day) ? 0 : -1, "aria-label": labelDayButton(date, dayModifiers, labelOptions, dateLib), onClick: handleDayClick(day, dayModifiers), onBlur: handleDayBlur(day, dayModifiers), onFocus: handleDayFocus(day, dayModifiers), onKeyDown: handleDayKeyDown(day, dayModifiers) }, formatDay(date, formatOptions, dateLib))) : (formatDay(day.date, formatOptions, dateLib))));
                                    })));
                            })))));
                })),
            props.footer && (react_1.default.createElement(components.Footer, { className: classNames[UI_js_1.UI.Footer], style: styles?.[UI_js_1.UI.Footer], role: "status", "aria-live": "polite" }, props.footer)))));
}
//# sourceMappingURL=DayPicker.js.map