"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMulti = useMulti;
const react_1 = __importDefault(require("react"));
function useMulti(props, dateLib) {
    const { selected, required, onSelect, mode } = props;
    const [dates, setDates] = react_1.default.useState(mode !== "multiple" ? undefined : selected);
    const { isSameDay, Date } = dateLib;
    // Update the selected date if the required flag is set.
    react_1.default.useEffect(() => {
        if (mode !== "multiple")
            return;
        if (required && dates === undefined) {
            setDates([new Date()]);
        }
    }, [required, dates, Date, mode]);
    // Update the selected date if the selected value from props changes.
    react_1.default.useEffect(() => {
        if (mode !== "multiple")
            return;
        setDates(selected);
    }, [mode, selected]);
    const isSelected = (date) => {
        return dates?.some((d) => isSameDay(d, date)) ?? false;
    };
    const { min, max } = props;
    const setSelected = (triggerDate, modifiers, e) => {
        let newDates = [...(dates ?? [])];
        if (isSelected(triggerDate)) {
            if (dates?.length === min) {
                // Min value reached, do nothing
                return;
            }
            if (required && dates?.length === 1) {
                // Required value already selected do nothing
                return;
            }
            newDates = dates?.filter((d) => !isSameDay(d, triggerDate));
        }
        else {
            if (dates?.length === max) {
                // Max value reached, reset the selection to date
                newDates = [triggerDate];
            }
            else {
                // Add the date to the selection
                newDates = [...newDates, triggerDate];
            }
        }
        onSelect?.(newDates, triggerDate, modifiers, e);
        setDates(newDates);
        return newDates;
    };
    return {
        selected: dates,
        handleSelect: setSelected,
        isSelected
    };
}
//# sourceMappingURL=useMulti.js.map