"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRange = useRange;
const react_1 = __importDefault(require("react"));
const index_js_1 = require("../utils/index.js");
const isDateInRange_js_1 = require("../utils/isDateInRange.js");
function useRange(props, dateLib) {
    const { mode, disabled, selected, required, onSelect } = props;
    const { differenceInCalendarDays } = dateLib;
    const [range, setRange] = react_1.default.useState(mode === "range" ? selected : undefined);
    // Update the selected date if the required flag is set.
    react_1.default.useEffect(() => {
        if (mode !== "range")
            return;
        if (required && range === undefined) {
            setRange({ from: undefined, to: undefined });
        }
    }, [required, range, mode]);
    // Update the selected date if the selected changes.
    react_1.default.useEffect(() => {
        if (mode !== "range")
            return;
        if (range === selected)
            return;
        setRange(selected);
    }, [mode, range, selected]);
    const isSelected = (date) => range && (0, isDateInRange_js_1.isDateInRange)(date, range, dateLib);
    const setSelected = (triggerDate, modifiers, e) => {
        if (mode !== "range")
            return;
        const newRange = triggerDate
            ? (0, index_js_1.addToRange)(triggerDate, range, dateLib)
            : undefined;
        const { min, max } = props;
        if (min) {
            if (newRange?.from &&
                newRange.to &&
                differenceInCalendarDays(newRange.to, newRange.from) < min - 1) {
                newRange.from = triggerDate;
                newRange.to = undefined;
            }
        }
        if (max) {
            if (newRange?.from &&
                newRange.to &&
                differenceInCalendarDays(newRange.to, newRange.from) >= max) {
                newRange.from = triggerDate;
                newRange.to = undefined;
            }
        }
        if (newRange?.from && newRange.to) {
            let newDate = newRange.from;
            while (dateLib.differenceInCalendarDays(newRange.to, newDate) > 0) {
                newDate = dateLib.addDays(newDate, 1);
                if (disabled && (0, index_js_1.dateMatchModifiers)(newDate, disabled, dateLib)) {
                    newRange.from = triggerDate;
                    newRange.to = undefined;
                    break;
                }
            }
        }
        setRange(newRange);
        onSelect?.(newRange, triggerDate, modifiers, e);
        return newRange;
    };
    const isRangeStart = (date) => {
        return (range && range.from && range.to && dateLib.isSameDay(date, range.from));
    };
    const isRangeEnd = (date) => {
        return range && range.to && dateLib.isSameDay(date, range.to);
    };
    const isRangeMiddle = (date) => {
        return (range &&
            range.from &&
            range.to &&
            isSelected(date) &&
            !isRangeStart(date) &&
            !isRangeEnd(date));
    };
    return {
        selected: range,
        handleSelect: setSelected,
        isSelected,
        isRangeStart,
        isRangeEnd,
        isRangeMiddle
    };
}
//# sourceMappingURL=useRange.js.map