import type { CalendarWeek, CalendarDay, CalendarMonth } from "./classes/index.js";
import type { DayPickerProps } from "./types/props.js";
import type { DateLib } from "./types/shared.js";
/**
 * The hook to get and handle the calendar state.
 *
 * @see https://daypicker.dev/next/guides/custom-components
 */
export interface UseCalendar {
    today: Date;
    /** All the unique dates displayed to the calendar. */
    dates: Date[];
    /**
     * All the days displayed in the calendar. As opposite from
     * {@link CalendarContext.dates}, it may return duplicated dates when shown
     * outside the month.
     */
    days: CalendarDay[];
    /** The months displayed in the calendar. */
    weeks: CalendarWeek[];
    /** The months displayed in the calendar. */
    months: CalendarMonth[];
    /**
     * The month displayed as first the calendar. When `numberOfMonths` is greater
     * than `1`, it is the first of the displayed months.
     */
    firstMonth: Date;
    /**
     * The month displayed as last the calendar. When `numberOfMonths` is greater
     * than `1`, it is the last of the displayed months.
     */
    lastMonth: Date;
    /** The next month to display. */
    nextMonth: Date | undefined;
    /** The previous month to display. */
    previousMonth: Date | undefined;
    /**
     * The month where the navigation starts. `undefined` if the calendar can be
     * navigated indefinitely to the past.
     */
    navigationStartMonth: Date | undefined;
    /**
     * The month where the navigation ends. `undefined` if the calendar can be
     * navigated indefinitely to the past.
     */
    navigationEndMonth: Date | undefined;
    /** Set the first month displayed in the calendar. */
    setFirstMonth: (date: Date) => void;
    /** Navigate to the specified month. Will fire the `onMonthChange` callback. */
    goToMonth: (month: Date) => void;
    /** Navigate to the next month. */
    goToNextMonth: () => void;
    /** Navigate to the previous month. */
    goToPreviousMonth: () => void;
    /**
     * Navigate to the specified date. If the second parameter (refDate) is
     * provided and the date is before the refDate, then the month is set to one
     * month before the date.
     *
     * @param day - The date to navigate to.
     * @param dateToCompare - Optional. If `date` is before `dateToCompare`, the
     *   month is set to one month before the date.
     */
    goToDay: (day: CalendarDay) => void;
    /** Whether the given date is included in the displayed months. */
    isDayDisplayed: (day: CalendarDay) => boolean;
}
/** @private */
export declare function useCalendar(props: Pick<DayPickerProps, "fromYear" | "toYear" | "startMonth" | "endMonth" | "month" | "defaultMonth" | "today" | "numberOfMonths" | "disableNavigation" | "onMonthChange" | "ISOWeek">, dateLib: DateLib): UseCalendar;
