"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDateInRange = isDateInRange;
const index_js_1 = require("../lib/index.js");
/**
 * Determines whether a given date is inside a specified date range.
 *
 * @group Utilities
 */
function isDateInRange(date, range, 
/** @ignore */
dateLib = index_js_1.dateLib) {
    let { from, to } = range;
    const { differenceInCalendarDays, isSameDay } = dateLib;
    if (from && to) {
        const isRangeInverted = differenceInCalendarDays(to, from) < 0;
        if (isRangeInverted) {
            [from, to] = [to, from];
        }
        const isInRange = differenceInCalendarDays(date, from) >= 0 &&
            differenceInCalendarDays(to, date) >= 0;
        return isInRange;
    }
    if (to) {
        return isSameDay(to, date);
    }
    if (from) {
        return isSameDay(from, date);
    }
    return false;
}
//# sourceMappingURL=isDateInRange.js.map