import React from "react";
export function useSingle(props, dateLib) {
    const { selected, required, onSelect, mode } = props;
    const [date, setDate] = React.useState(mode !== "single" ? undefined : selected);
    const { isSameDay, Date, startOfDay } = dateLib;
    // Update the selected date if the required flag is set.
    React.useEffect(() => {
        if (mode !== "single")
            return;
        if (required && date === undefined) {
            setDate(startOfDay(new Date()));
        }
    }, [required, date, Date, startOfDay, mode]);
    // Update the selected date if the `selected` value changes.
    React.useEffect(() => {
        if (mode !== "single")
            return;
        setDate(selected);
    }, [mode, selected]);
    const isSelected = (compareDate) => {
        return date ? isSameDay(date, compareDate) : false;
    };
    const setSelected = (triggerDate, modifiers, e) => {
        if (mode !== "single")
            return;
        let newDate = triggerDate;
        if (!required && date && date && isSameDay(triggerDate, date)) {
            // If the date is the same, clear the selection.
            newDate = undefined;
        }
        setDate(newDate);
        if (required) {
            onSelect?.(newDate, triggerDate, modifiers, e);
        }
        else {
            onSelect?.(newDate, triggerDate, modifiers, e);
        }
        return newDate;
    };
    return {
        selected: date,
        handleSelect: setSelected,
        isSelected
    };
}
//# sourceMappingURL=useSingle.js.map