import type { DateAfter, DateBefore, DateInterval, DateRange, DayOfWeek, DayPickerProps, PropsMulti, PropsRange, PropsSingle } from "../types/index.js";
/**
 * Returns true if `matcher` is of type `DateInterval`.
 *
 * @group Utilities
 */
export declare function isDateInterval(matcher: unknown): matcher is DateInterval;
/**
 * Returns true if `value` is a `DateRange` type.
 *
 * @group Utilities
 */
export declare function isDateRange(value: unknown): value is DateRange;
/**
 * Returns true if `value` is of type `DateAfter`.
 *
 * @group Utilities
 */
export declare function isDateAfterType(value: unknown): value is DateAfter;
/**
 * Returns true if `value` is of type `DateBefore`.
 *
 * @group Utilities
 */
export declare function isDateBeforeType(value: unknown): value is DateBefore;
/**
 * Returns true if the props are for a single selection mode.
 *
 * @group Utilities
 */
export declare function isSingle(props: DayPickerProps): props is DayPickerProps & PropsSingle;
/**
 * @deprecated This function has been renamed Use `isSingle` instead.
 * @protected
 */
export declare const isDayPickerSingle: typeof isSingle;
/**
 * Returns true if the props are for a multiple selection mode.
 *
 * @group Utilities
 */
export declare function isMulti(props: DayPickerProps): props is DayPickerProps & PropsMulti;
/**
 * @deprecated This function has been renamed Use `isMulti` instead.
 * @protected
 */
export declare const isDayPickerMultiple: typeof isMulti;
/**
 * Returns true if the props are for a range selection mode.
 *
 * @group Utilities
 */
export declare function isRange(props: DayPickerProps): props is DayPickerProps & PropsRange;
/**
 * Returns true if `value` is a `DayOfWeek` type.
 *
 * @group Utilities
 */
export declare function isDayOfWeekType(value: unknown): value is DayOfWeek;
/**
 * @deprecated This function has been renamed Use `isRange` instead.
 * @protected
 */
export declare const isDayPickerRange: typeof isRange;
